@@ -63,7 +63,7 @@ See L<https://github.com/ukautz/Net-Amazon-DynamoDB> for latest release.
 use Moose;
 
 use v5.10;
-use version 0.74; our $VERSION = qv( "v0.1.15" );
+use version 0.74; our $VERSION = qv( "v0.1.16" );
 
 use Carp qw/ croak /;
 use Data::Dumper;
@@ -1362,13 +1362,8 @@ sub batch_get_item {
         process_all => undef,
         consistent  => undef
     };
-<<<<<<< HEAD
     $args_ref->{ consistent } //= $self->read_consistent();
-    
-=======
 
-
->>>>>>> b608dcac8f3a6d070519ad72560c8ceb2bd17d4f
     # check definition
     my %table_map;
     foreach my $table( keys %$tables_ref ) {
